%define daemon_user monitor
%define htmlroot /var/www/html
%define httpconfdir httpd/conf.d
%define daemon_group apache
%define apache_group apache
Requires: php-cli
Name: op5-synergy-processor
Version: %{op5version}
Release: %{op5release}%{?dist}
License: op5 Software License
Packager: build@op5
Vendor: op5 AB
BuildRoot: %{_tmppath}/%{name}-%{version}
Summary: Business service handler processor
Group: Applications/System
Prefix: /opt/synergy
BuildArch: noarch
Requires: lua, monitor-livestatus, monitor-nacoma, monitor-ninja
Requires: op5-synergy-luapack >= 1.1.1-beta3
Requires: op5-monitor-supported-database
Requires: python
Requires: merlin
Requires: op5-monitor-user
BuildRequires: lua
BuildRequires: op5-monitor-supported-database
BuildRequires: merlin
BuildRequires: op5-synergy-luapack >= 1.1.1-beta3
BuildRequires: monitor-livestatus
BuildRequires: monitor-ninja-devel
%if 0%{?rhel} >= 7
BuildRequires: systemd
%endif
Source: %name-%version.tar.gz
Obsoletes: op5-synergy <= 1.1.0
Provides: op5-synergy

%description
Handles business services according to user defined rules.

%package test
Summary: Test files for op5-synergy-processor
Group: op5/Monitor
Requires: phantomjs
Requires: op5-synergy-processor = %version
Requires: portal
Requires: monitor-ninja
Requires: monitor-ninja-test
Requires: monitor-livestatus
Requires: php-phpunit-PHPUnit
%if 0%{?rhel} <= 6
Requires: ruby20
Requires: ruby20-devel
%else
Requires: ruby
Requires: ruby-devel
%endif
# our tests won't run without this particular supported-database
Requires: op5-mysql

%description test
Misc test files for op5-synergy-processor

%prep
rm -rf %buildroot
%setup -q

%build
make

%install
make INSTALL_TOP=%buildroot%prefix install
mkdir -p -m 744 %buildroot/opt/monitor/etc/extra-oconf/synergy
mkdir -p -m 777 %buildroot%prefix/var/spool
mkdir -p -m 777 %buildroot%prefix/var/queue
mkdir --parents %buildroot/etc
%if 0%{?rhel} >= 7
mkdir --parents %{buildroot}%{_unitdir}
cp op5build/synergy.service %{buildroot}%{_unitdir}/synergy.service
%else
mkdir --parents %buildroot/etc/op5kad/conf.d
cp op5kad/synergy.kad %buildroot/etc/op5kad/conf.d/
mkdir --parents --mode 755 %buildroot/etc/init.d
cp etc/init.d/synergy %buildroot/etc/init.d/synergy
%endif
mkdir -p %buildroot/opt/monitor/op5/ninja/modules
cp -r synergy %buildroot/opt/monitor/op5/ninja/modules
rm -rf %buildroot/opt/monitor/op5/ninja/modules/synergy/src
mkdir -p -m 744 %buildroot/opt/monitor/op5/nacoma/hooks/save
cp -r external/hook/* %buildroot/opt/monitor/op5/nacoma/hooks/save
cp -r external/opt/* %buildroot/opt/
mkdir -p -m 755 %buildroot%prefix/etc/rules/repo
mkdir -p -m 755 %buildroot%prefix/etc/rules/custom/repo
mkdir -p -m 755 %buildroot%prefix/etc/bps
cp -r etc/op5-backup %buildroot/etc/
mkdir -p -m 755 %buildroot%prefix/sql
cp -a sql/* %buildroot%prefix/sql/
cp Makefile %buildroot%prefix/
cp -a test %buildroot%prefix/test
mkdir -p %buildroot%prefix/test/var
cp -a features %buildroot%prefix/features
mkdir -p %buildroot%prefix/etc/sample
cp op5build/sample/Test-Drive.lua %buildroot%prefix/etc/sample

%post
# Adjust rules and their file names
if ! python %prefix/scripts/fix-rules.py; then
	echo "Failed to fix rules."
	echo "Please rerun %prefix/scripts/fix-rules.py manually and"
	echo "contact OP5 Support <https://www.op5.com/support/> if that doesn't solve the issue."
	sleep 5
fi

# MON-8668 & MON-9078: GUI generated files needs to be removable by daemon
find %prefix/var/queue %prefix/var/spool -maxdepth 1 -type d -exec chmod g+w {} \;

# Verify that mysql-server is installed and running before executing sql scripts
# TODO: Is it really a good idea to hide mysql errors?
$(mysql -Be "quit" 2>/dev/null)
if [ $? -eq 0 ]; then
	sh %prefix/sql/mysql/install-mysql.sh
else
	echo "WARNING: mysql-server is not installed or not running."
	echo "If MySQL database is to be used you need to maually run database"
	echo "install/upgrade procedures to complete the setup of %name"
fi

if  grep -q '^cfg_dir=extra-oconf$' /opt/monitor/etc/nagios.cfg; then
	if test -d /opt/monitor/etc/synergy; then
		cp -a /opt/monitor/etc/synergy /opt/monitor/etc/extra-oconf/
		sed -i --follow-symlinks '/cfg_dir=\/opt\/monitor\/etc\/synergy/d' /opt/monitor/etc/nagios.cfg
		mon restart
	fi
fi

# install sample on first install
if [ "$1" -le 1 ]; then
	for bs in %prefix/etc/sample/*; do
		cp $bs %prefix/etc/bps/$(basename $bs)
		chmod 0664 %prefix/etc/bps/$(basename $bs)
		chown %apache_group:%daemon_group %prefix/etc/bps/$(basename $bs)
	done
fi

if [ "$1" -eq 1 ];
then
	echo "Verifying names..."
	if php /opt/monitor/op5/nacoma/api/monitor.php -t service_template -a list_objects -u monitor 2>&1 | grep -i duplicate | grep -q 'bizproc_service' ||
		php /opt/monitor/op5/nacoma/api/monitor.php -t command -a list_objects -u monitor 2>&1 | grep -i duplicate | grep -q 'bizproc_pas'
	then
		mkdir -p /opt/synergy/etc/monitor
		mv /opt/monitor/etc/synergy/* /opt/synergy/etc/monitor/
		echo "
************************************
Name clash detected.
For correct work of op5 business services it needs to install
service template bizproc_service and check command bizproc_pas.
Seems that you already have the objects with these names,
so we skipped this step to keep the config sane.
Please, rename your monitor objects, then manually move files for business services to work properly:
  mv /opt/synergy/etc/monitor/* /opt/monitor/etc/synergy
************************************"
	fi

fi

%if 0%{?rhel} >= 7
systemctl reload naemon || true
%else
service monitor reload || true
%endif

if [ "$1" -gt 0 ];
then
%if 0%{?rhel} >= 7
	systemctl daemon-reload
	systemctl enable synergy.service
	systemctl start synergy
%else
	chkconfig --add synergy
	service synergy start
%endif
fi

%preun
if [ "$1" -eq 0 ];
then
%if 0%{?rhel} >= 7
    systemctl stop processor
    systemctl stop synergy
    systemctl restart naemon
%else
    service processor stop
    service synergy stop
    service monitor restart
%endif
fi

%files
%defattr(664,%daemon_user,%daemon_group,775)
/opt/monitor/op5/ninja/modules/synergy/
%prefix/etc
%prefix/var
%prefix/sql
%dir /opt/monitor/etc/extra-oconf/synergy
%config(noreplace) /opt/monitor/etc/extra-oconf/synergy/command.cfg
%config(noreplace) /opt/monitor/etc/extra-oconf/synergy/services.cfg
%dir %prefix/var/run
%if 0%{?rhel} >= 7
%attr(664, root, root) %{_unitdir}/synergy.service
%else
/etc/op5kad/conf.d/synergy.kad
%attr(755,root,root) /etc/init.d/synergy
%endif
%attr(755,root,root) %prefix/scripts/*
%attr(755,root,root) %prefix/bin/*
%attr(755,root,root) %prefix/share/*
%attr(755,root,root) %prefix/etc/config.lua
%attr(755,root,root) /opt/monitor/op5/nacoma/hooks/save/synergy_hook.py
%attr(644,root,root) /opt/monitor/op5/nacoma/hooks/save/synergy_hook.pyc
%attr(644,root,root) /opt/monitor/op5/nacoma/hooks/save/synergy_hook.pyo
%attr(664,root,root) /opt/synergy/etc/sample
%attr(644,root,root) /etc/op5-backup/modules/external/op5-synergy

%exclude %prefix/test
%exclude %prefix/features
%exclude %prefix/Makefile

%files test
%defattr(644,%daemon_user,%daemon_group,755)
%prefix/test
%prefix/features
%attr(755,root,root) %prefix/test/lunit/lunit
%prefix/Makefile

%clean
rm -rf %buildroot
